resolve

package
v0.12.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 30, 2025 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func FieldRules

FieldRules returns the FieldRules option set for the FieldDescriptor.

func MessageRules

MessageRules returns the MessageRules option set for the MessageDescriptor.

func OneofRules

OneofRules returns the OneofRules option set for the OneofDescriptor.

func PredefinedRules

func PredefinedRules(desc protoreflect.FieldDescriptor) (*validate.PredefinedRules, error)

PredefinedRules returns the PredefinedRules option set for the FieldDescriptor. Note that this value is only meaningful if it is set on a field or extension of a field rule message. This method is provided for convenience.

Types

This section is empty.

Jump to