Documentation
¶
Index ¶
- func FieldRules(desc protoreflect.FieldDescriptor) (*validate.FieldRules, error)
- func MessageRules(desc protoreflect.MessageDescriptor) (*validate.MessageRules, error)
- func OneofRules(desc protoreflect.OneofDescriptor) (*validate.OneofRules, error)
- func PredefinedRules(desc protoreflect.FieldDescriptor) (*validate.PredefinedRules, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FieldRules ¶
func FieldRules(desc protoreflect.FieldDescriptor) (*validate.FieldRules, error)
FieldRules returns the FieldRules option set for the FieldDescriptor.
func MessageRules ¶
func MessageRules(desc protoreflect.MessageDescriptor) (*validate.MessageRules, error)
MessageRules returns the MessageRules option set for the MessageDescriptor.
func OneofRules ¶
func OneofRules(desc protoreflect.OneofDescriptor) (*validate.OneofRules, error)
OneofRules returns the OneofRules option set for the OneofDescriptor.
func PredefinedRules ¶
func PredefinedRules(desc protoreflect.FieldDescriptor) (*validate.PredefinedRules, error)
PredefinedRules returns the PredefinedRules option set for the FieldDescriptor. Note that this value is only meaningful if it is set on a field or extension of a field rule message. This method is provided for convenience.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.